@@ -1,9 +1,8 @@
 __author__ = "Wytze Bruinsma"
 
+import newlinejson as nlj
 import random
 import string
-
-import newlinejson as nlj
 from google.cloud import storage
 
 from vaknl_gcp.Bigquery import BigqueryClient
@@ -42,14 +41,14 @@ class StorageClient(object):
             blob.delete()
 
         if len(new_blobs) > 1:
-            self.__rec_compose(new_blobs, blob_name,  table_ref, write_disposition, n + 1)
+            self.__rec_compose(new_blobs, blob_name, table_ref, write_disposition, n + 1)
         else:
             self.bigquery_client.write_disposition_bucket(blob_name=new_blobs[0].name, table_ref=table_ref,
                                                           write_disposition=write_disposition)
             for blob in new_blobs:
                 blob.delete()
 
-    def storage_to_bigquery(self, objects: list, table_ref, write_disposition, batch_size=5000):
+    def storage_to_bigquery(self, objects: list, table_ref, write_disposition, batch_size=5000, objects_name=None):
         """
         Function that stores data into multiple storage blobs. Afterwards these wil be composed into one storage blob.
         The reason for this process is to downsize the sie of the data send to Google Cloud Storage.
@@ -59,12 +58,15 @@ class StorageClient(object):
             table_ref: dataset_name.table_name
             write_disposition: how to write to google bigquery
             batch_size: row size blobs will be created in google storage before they are composed and send to bigquery
+            objects_name: name of the them objects stored in storage 
         """
 
         assert len(objects) > 0, 'List is empty. No data is send'
 
-        objects_name = objects[0].__class__.__name__  # retrieve name of the first object
-        random_string = ''.join(random.choice(string.ascii_lowercase) for _ in range(12))  # Make blob_base_name unique so processes don't interact
+        if objects_name:
+            objects_name = objects[0].__class__.__name__  # retrieve name of the first object
+        random_string = ''.join(random.choice(string.ascii_lowercase) for _ in
+                                range(12))  # Make blob_base_name unique so processes don't interact
         blob_base_name = f'{objects_name}_{random_string}'  # Generate a dynamic name from the object
         blobs = []
 
@@ -77,32 +79,35 @@ class StorageClient(object):
             blobs.append(blob)
             blob.upload_from_string(nl_json_batch)
 
-        self.__rec_compose(blobs, blob_base_name, self.bucket, table_ref, write_disposition)
+        self.__rec_compose(blobs=blobs, blob_name=blob_base_name, table_ref=table_ref,
+                           write_disposition=write_disposition)
 
-    def single_storage_to_bigquery(self, object, table_ref, write_disposition, batch_size=500):
+    def single_storage_to_bigquery(self, object, table_ref, write_disposition, batch_size=500, object_name=None):
         """
         Function that stores data into a storage blob. Then check if there are more than the batch_size. 
         If so it will compose similar blobs and send them to google bigquery.
         The reason for this process is to not stream single rows of data into bigquery but wait until there are more and than send them together.
         
-        Args:
+        Args:            
             object: dataclass
             table_ref: dataset_name.table_name
             write_disposition: how to write to google bigquery
             batch_size: how many blobs until composing and sending to google bigquery
+            object_name: name of the them object stored in storage 
         """
-
-        object_name = object.__class__.__name__  # retrieve name of the object
+        if object_name:
+            object_name = object.__class__.__name__  # retrieve name of the object
         blob_base_name = f'{object_name}_{generate_random_string()}'  # Generate a dynamic name from the object
 
-        nl_json = nlj.dumps(rec_to_json(object))
+        nl_json = nlj.dumps([rec_to_json(object)])
         blob = self.bucket.blob(f'import/{object_name}/{blob_base_name}.json')
         blob.upload_from_string(nl_json)
 
-        blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'{object_name}/')
+        blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'import/{object_name}/')
 
         if len(blobs) > batch_size:
-            self.__rec_compose(blobs, blob_base_name, self.bucket, table_ref, write_disposition)
+            self.__rec_compose(blobs=blobs, blob_name=f'{object_name}_{generate_random_string()}', table_ref=table_ref,
+                               write_disposition=write_disposition)
 
     def get_blobs_from_bucket(self, bucket_name):
         """
@@ -116,7 +121,7 @@ class StorageClient(object):
 
     def upload_from_string(self, blob, string):
         """
-        :arg
+        Args:
             blob: blob
             string: data to write in the blob
         Return:
@@ -125,6 +130,15 @@ class StorageClient(object):
         blob.upload_from_string(string)
         return blob.public_url
 
+    def get_bucket(self, bucket_name):
+        """
+        Args:
+            string: bucket_name
+        Return:
+            string: url
+        """
+        return self.storage_client.get_bucket(bucket_name)
+
     def list_blobs_with_prefix(self, bucket_name, prefix, delimiter=None):
         """
         Lists all the blobs in the bucket that begin with the prefix.
@@ -167,7 +181,7 @@ class StorageClient(object):
         if delimiter:
             return [prefix for prefix in blobs.prefixes]
         else:
-            return [blob.name for blob in blobs]
+            return list(blobs)
 
 
 def generate_random_string():
